@@ -2,6 +2,7 @@ import asyncio
 import json
 import codecs
 import struct
+import logging
 
 from pytonlib.tonlibjson import TonLib
 from pytonlib.utils.address import prepare_address, detect_address
@@ -13,7 +14,7 @@ from pathlib import Path
 from datetime import datetime
 from copy import deepcopy
 
-from loguru import logger
+logger = logging.getLogger(__name__)
 
 
 class TonlibClient:
